@@ -1123,7 +1123,7 @@ def make(*args,server,port,online):
     last_String = 'package Main;\n\n'+addition+javacode
     files.write(last_String)
     files.close()
-    minepy = "python minepy.py"
+    minepy = "minepy"
     if server == True:
         minepy += " -s"
     if port == True:
